@@ -3,10 +3,7 @@ import os
 from pathlib import Path
 from robot.api import logger
 from time import sleep
-try:
-    from apiclient import Apiclient
-except ImportError:
-    from .apiclient import Apiclient
+from .apiclient import Apiclient
 
 TEST_TEMPLATE_ID = 1
 TEST_TYPE_ID = 3
@@ -21,13 +18,13 @@ TEST_STATUS_RETEST = 4
 TEST_STATUS_CUSTOM_6 = 6
 TEST_STATUS_CUSTOM_7 = 7
 
-__version__ = "1.0.0"
+VERSION = "1.0.0"
 
 class TestrailLibrary:
     
-    ROBOT_LIBRARY_SCOPE = 'TEST SUITE'
-    ROBOT_LIBRARY_VERSION = __version__
-
+    ROBOT_LIBRARY_VERSION = VERSION
+    ROBOT_LIBRARY_SCOPE = "GLOBAL"
+    
     class TestCaseResult:
 
         def __init__(self):
@@ -56,19 +53,30 @@ class TestrailLibrary:
             return getattr(self, key)
 
     def __init__(self, server=None, username=None, key=None):
+
         self.server = server
         self.client = None
+        self.expect_duplicates = False
         if server:
             self.client = Apiclient(server)
             self.client.user = username
             self.client.password = key
         self.test_case_result = self.TestCaseResult()
 
+    def __handle_duplicates(self, msg):
+        if self.expect_duplicates:
+            logger.warn(msg)
+        else:
+            raise DuplicateException(msg)
+
     def connect_to_testrail(self, server, username, key):
         self.client = Apiclient(server)
         self.client.user = username
         self.client.password = key
         self.__check_credentials()
+    
+    def set_expect_duplicates(self, state):
+        self.expect_duplicates = state
 
     def set_test_case_result(self, **kwargs):
         for key, value in kwargs.items():
@@ -181,21 +189,19 @@ class TestrailLibrary:
         response = self.client.send_get(url)
         return response
 
-    def get_suite_by_name(self, project_id, suite_name):
+    def get_suites_by_name(self, project_id, suite_name, expect_duplicates=False):
         suites = self.get_suites_in_project(project_id)
         if not isinstance(suites, list): suites = []
         suite = list(filter(lambda x: x.get('name') == suite_name, suites))
-        if suite and len(suite) == 1:
-            return suite[0]
-        elif suite and len(suite) > 1:
-            logger.info(suite)
-            raise DuplicateException(f'More than 1 suite found with name {suite_name} for project {project_id}')
-        return {}
+        if suite and len(suite) > 1:
+            msg = f'More than 1 suite found with name {suite_name} for project {project_id}'
+            self.__handle_duplicates(msg)
+        return suite
 
     def add_suite(self, project_id, suite_name, description):
-        suite = self.get_suite_by_name(project_id, suite_name)
+        suite = self.get_suites_by_name(project_id, suite_name)
         if suite:
-            return suite
+            return suite[0]
         else:
             url = f'add_suite/{project_id}'
             # logger.console(url)
@@ -233,14 +239,14 @@ class TestrailLibrary:
         response = self.client.send_get(url)
         return response
 
-    def get_sections_by_name(self, project_id, suite_id, section_name, expect_duplicates=False):
+    def get_sections_by_name(self, project_id, suite_id, section_name):
         sections = self.get_sections(project_id, suite_id)
         if not isinstance(sections, list): sections = []
         section = list(filter(lambda x: x.get('name') == section_name, sections))
-        if section:
-            if not expect_duplicates and len(section) > 1:
-                logger.warn(f'Found more than 1 section with name {section_name} for project' 
-                '{project_id}, suite {suite_id}...returning first section')
+        if section and len(section) > 1:
+            msg = f'Found more than 1 section with name {section_name} for ' \
+                  f'project {project_id}, suite {suite_id}...returning first section'
+            self.__handle_duplicates(msg)
         return section
         
     def add_section(self, project_id, name, description, suite_id, parent_id=None):
@@ -299,14 +305,15 @@ class TestrailLibrary:
         url = f'get_cases/{project_id}&suite_id={suite_id}'
         return self.__get_with_offset(url, "cases", **kwargs)
     
-    def get_cases_by_name(self, project_id, suite_id, section_id, title, expect_duplicates=False):
+    def get_cases_by_name(self, project_id, suite_id, section_id, title):
         cases = self.get_cases(project_id, suite_id=suite_id)
         if not isinstance(cases, list): cases = []
         case = list(filter(lambda x: x.get('title') == title and x.get('section_id') == section_id,
                                            cases))
-        if not expect_duplicates and len(case) > 1:
-            raise DuplicateException(f'More than 1 case found with name {title} for project {project_id} ' 
-                    f'suite {suite_id} and section {section_id}: {case}')
+        if case and len(case) > 1:
+            msg = f'More than 1 case found with name {title} for project {project_id} ' \
+                    f'suite {suite_id} and section {section_id}: {case}'
+            self.__handle_duplicates(msg)
         return case
 
     def add_case(self, project_id, suite_id, title, section_id=None, **kwargs):
@@ -317,17 +324,19 @@ class TestrailLibrary:
                 section = self.add_section(project_id, name=section_name, description=kwargs.get('description') or 
                 'New Section', suite_id=suite_id, parent_id=kwargs.get('parent_id'))
             else:
+                if len(sections) > 1:
+                    return {}
                 section = sections[0]
             section_id = section.get('id')
         case = self.get_cases_by_name(project_id, suite_id, section_id, title) 
         if case: 
             if len(case) > 1:
-                logger.warn(f'More than 1 cases found with name {title} for project {project_id} '
-                f'and suite {suite_id}')
-            return case[0]
+                return {}
+            response = case[0]
         else:
             response = self.add_case_to_section(section_id, title, **kwargs)
-            return response
+        logger.info(response)
+        return response
 
     def add_case_to_section(self, section_id, title, **kwargs):
         template_id = kwargs.get('template_id') or TEST_TEMPLATE_ID
@@ -374,12 +383,13 @@ class TestrailLibrary:
         logger.info(response)
         return response
 
-    def get_runs_by_name(self, project_id, run_name, expect_duplicates=False):
+    def get_runs_by_name(self, project_id, run_name):
         runs = self.get_runs(project_id)
         if not isinstance(runs, list): runs = []
         run = list(filter(lambda x: x.get('name')== run_name, runs))
-        if not expect_duplicates and len(run) > 1: 
-            raise DuplicateException(f'Found more than 1 test runs with name {run_name} for project {project_id}')
+        if run and len(run) > 1: 
+            msg = f'Found more than 1 test runs with name {run_name} for project {project_id}'
+            self.__handle_duplicates(msg)
         return run
     
     def add_run(self, project_id, suite_id, name, description, include_all=True, refs=None, case_ids=None):
@@ -388,8 +398,7 @@ class TestrailLibrary:
         run = self.get_runs_by_name(project_id, name)
         if run:
             if len(run) > 1:
-                logger.warn(f'Found more than 1 run with name {name} for project {project_id}...'
-                        f'returning only first one')
+                return {}
             return run[0]
         description = description
         include_all = include_all
@@ -412,12 +421,14 @@ class TestrailLibrary:
     def update_run(self, run_id, **kwargs):
         url = f'update_run/{run_id}'
         response = self.client.send_post(url, data=kwargs)
+        logger.info(response)
         return response
 
     def close_run(self, run_id):
         url = f'close_run/{run_id}'
         #logger.info(f'Adding attachment file {filepath} to run {run_id}')
         response = self.client.send_post(url, data={})
+        logger.info(response)
         return response
 
     # def delete_run(self, run_id):
@@ -453,6 +464,7 @@ class TestrailLibrary:
             "elapsed": elapsed
         }
         response = self.client.send_post(url, data=data)
+        logger.info(response)
         return response
     
     def add_result(self):
@@ -462,20 +474,16 @@ class TestrailLibrary:
     # ATTACHMENTS
     def add_attachment_to_test_run(self, run_id, filepath):
         url = f'add_attachment_to_run/{run_id}'
-        # logger.console(url)
         logger.info(f'Adding attachment file {filepath} to run {run_id}')
         response = self.client.send_post(url, data=filepath)
+        logger.info(response)
         return response
 
     def get_attachments_for_run(self, run_id:int, **kwargs):
         logger.info(f'Getting attachments for run {run_id}')
         url = f'get_attachments_for_run/{run_id}'
-        #client = self.get_testrail_client()
         return self.__get_with_offset(url, "attachments", **kwargs)
         
-        #response = self.client.send_get(url)
-        #return response.get('attachments') or []
-
     def delete_attachment(self, attachment:dict):
         attachment_id = attachment.get('id')
         attachment_name = attachment.get('name')
@@ -487,8 +495,8 @@ class TestrailLibrary:
 
     def delete_attachment_by_id(self, attachment_id):
         url = f'delete_attachment/{attachment_id}'
-        # logger.info(f'Deleting attachment {attachment_id}')
         response = self.client.send_post(url, data=None)
+        logger.info(response)
         return response
 
     def get_statuses(self):
@@ -496,18 +504,18 @@ class TestrailLibrary:
         """
         url = f'get_statuses/'
         response = self.client.send_get(url)
+        logger.info(response)
         return response
 
     def set_status_on_test_run(self, status_id, **kwargs):
-        #status_id = kwargs.get('status_id')
+        """
+        """
         statuses = self.get_statuses()
         status_ids = list(map(lambda x: x.get("id"), statuses))
         if str(status_id).lower() in ('pass', 'passed'):
             status_id = TEST_STATUS_PASSED
         elif str(status_id).lower() in ('fail', 'failed'):
             status_id = TEST_STATUS_FAILED
-        #elif str(status_id).lower() in ('skip', 'skipped'):
-        #    status_id = TEST_STATUS_NA
         elif str(status_id).isdigit() and int(status_id) == TEST_STATUS_UNTESTED:
             logger.error(f'Setting status to Untested is not supported')
             return {}
@@ -540,6 +548,8 @@ class TestrailLibrary:
             suite = self.add_suite(project_id=self.test_case_result.project_id,
                                            suite_name=self.test_case_result.suite_name,
                                            description=self.test_case_result.description)
+            if not suite:
+                return {}
             self.test_case_result.suite_id = suite.get("id")
         if self.test_case_result.section_name:
             section = self.add_section(name=self.test_case_result.section_name, 
@@ -547,6 +557,8 @@ class TestrailLibrary:
                                                    suite_id=self.test_case_result.suite_id,
                                                    description=self.test_case_result.description
                                                    )
+            if not section:
+                return {}
             self.test_case_result.section_id = section.get("id")
             self.test_case_result.section_name = section.get("name")
         if self.test_case_result.test_name:
@@ -555,6 +567,8 @@ class TestrailLibrary:
                                                   project_id=self.test_case_result.project_id,
                                                   suite_id=self.test_case_result.suite_id,
                                                   title=self.test_case_result.test_name)
+            if not test:
+                return {}
             self.test_case_result.test_id = test.get("id")
 
         if self.test_case_result.run_name:
@@ -563,6 +577,8 @@ class TestrailLibrary:
                                                 name=self.test_case_result.run_name,
                                                 description=self.test_case_result.description,
                                                 include_all=self.test_case_result.include_all)
+            if not run:
+                return {}
             self.test_case_result.run_id = run.get("id")
         response = self.add_result_for_case(run_id=self.test_case_result.run_id,
                                             case_id=self.test_case_result.test_id,
@@ -589,20 +605,25 @@ class TestrailLibrary:
             else:
                 logger.error(f'Error: {response}')
             return response
-        
-        
+              
     def delete_attachments_cleanup(self, run_id, max_to_keep=7):
         attachments = self.get_attachments_for_run(run_id)
         attachments_sorted = sorted(attachments, key=lambda x: x.get("created_on"))
+        deleted = []
         if len(attachments_sorted) > max_to_keep:
             to_delete = attachments_sorted[0:len(attachments) - max_to_keep]
+            
             for attachment in to_delete:
                 #print(f'Deleting attachment {attachment["name"]} from run {run_id}')
                 logger.info(f'Deleting attachment {attachment["name"]} from run {run_id}')
                 try:
                     deleted_response = self.delete_attachment(attachment)
+                    deleted.append(deleted_response)
                 except Exception as e:
-                    logger.error(e)        
-        
+                    logger.error(e)  
+        logger.info(deleted)      
+        return deleted
+
+
 class DuplicateException(BaseException):
     pass
\ No newline at end of file
