@@ -1,121 +1,15 @@
 import unittest
 import random
-import string
-import io
 from unittest.mock import patch
 from unittest.mock import Mock
-from TestrailLibrary import TestrailLibrary
-from TestrailLibrary.TestrailLibrary import DuplicateException 
+from TestrailLibrary.TestrailLibrary import TestrailLibrary as TR, DuplicateException
+from .mock_responses import *
 
-def get_sentence(count):
-    text = ''
-    for i in range(count):
-        text = f'{text} {get_random_string(random.randint(4, 10))}'  
-    return text
-
-def get_random_string(count=8):
-    return ''.join(random.choice(string.ascii_lowercase) for i in range(count))
-
-
-class BaseResponse:
-
-    def __init__(self, path, size=250, offset=0, limit=250) -> None:
-        self.offset = offset
-        self.limit = limit
-        self.size = min(size, limit)
-        self._links = {
-            "next": f"/api/v2/{path}&limit={size}&offset={offset+size}",
-            "prev": None if offset==0 else f"/api/v2/{path}&limit={limit}&offset={offset}"
-        }
-    
-    @property
-    def get(self):
-        return vars(self)
-
-class ProjectsResponse(BaseResponse):
-
-    def __init__(self, size=250, offset=0, limit=250) -> None:
-        super().__init__("get_projects", size=size, offset=offset, limit=limit)
-        self.projects = [
-                    {"id": i+offset+1, "name": f"Project {i+offset+1}", 
-                    "announcement": f"This is a demo project ", 
-                    "show_announcement": False, 
-                    "is_completed": False, 
-                    "completed_on": None, 
-                    "suite_mode": 3, 
-                    "url": f"https://example.testrail.net/index.php?/projects/overview/{i+offset+1}"
-                    } 
-                    for i in range(min(size, limit))
-                    ]
-
-class SectionsResponse(BaseResponse):
-
-    def __init__(self, size=250, offset=0, limit=250) -> None:
-        super().__init__("get_sections", size=size, offset=offset, limit=limit)
-        self.sections = [
-                    {"id": i+1000, "name": f"Section {i+1000}"} for i in range(min(size, limit))
-                    ]
-
-class RunsResponse(BaseResponse):
-
-    def __init__(self, size=250, offset=0, limit=250) -> None:
-        super().__init__("get_runs", size=size, offset=offset, limit=limit)
-        self.runs = [
-	            { "id": i+offset+1, "name": f"Test run {i+offset+1}", 'test_id': i+offset+1001, 
-                'status_id': random.randint(1, 5), 'created_on': random.randint(16700000, 16800000), 'assignedto_id': None, 
-                'comment': get_sentence(random.randint(3, 6)), 'version': None, 'elapsed': f'{random.randint(1, 120)}s', 'defects': None, 
-                'created_by': random.randint(35, 40), 'custom_step_results': None, 
-                'custom_environment': None, 'attachment_ids': []
-                } for i in range(min(size, limit))]
-                
-class ResultsResponse(BaseResponse):
-
-    def __init__(self, size=250, offset=0, limit=250) -> None:
-        super().__init__("get_results", size=size, offset=offset, limit=limit)
-        self.results = [{"id": i+5000, "test_id": i+1000, 
-                        "status_id": random.randint(1, 5),
-                        "comment": get_sentence(random.randint(3, 6))} for i in range(min(size, limit))
-                        ]
-        
-class CasesResponse(BaseResponse):
-
-    def __init__(self, size=250, offset=0, limit=250) -> None:
-        super().__init__("get_cases", size=size, offset=offset, limit=limit)
-        self.cases = [{"id": i+offset+1, "title": f'Case {i+offset+1}', 
-            "section_id": 1000} for i in range(min(size, limit))]
-
-class TestsResponse(BaseResponse):
-
-    def __init__(self, size=250, offset=0, limit=250) -> None:
-        super().__init__("get_tests", size=size, offset=offset, limit=limit)
-        self.tests = [{"id": i+offset+1, "title": f'Test Case {i+offset+1}', 
-            "status_id": random.randint(1, 5)} for i in range(min(size, limit))]
-
-class AttachmentsResponse(BaseResponse):
-
-    def __init__(self, size=250, offset=0, limit=250) -> None:
-        super().__init__("get_tests", size=size, offset=offset, limit=limit)
-        self.attachments = [{ "id": i+offset+1, "name": f"Image_{i+offset+1}.jpg", 
-                      "size": random.randint(500, 2500), "created_on": random.randint(1578900, 1600000),
-                     "project_id": 17, "case_id": random.randint(5000, 5030), 
-                     "user_id": random.randint(1, 5), 
-                     "result_id": None} 
-                     for i in range(min(size, limit))]
-
-
-GET_SUITES = [{"id": i+1, "name": f"Suite {i+1}"} for i in range(100)]
-GET_SUITE = GET_SUITES[0]
-
-STATUS_VALUES = ["passes", "blocked", "untested", "retest", "failed", "custom_6"]
-GET_STATUSES = [{"id": i+1, "name": STATUS_VALUES[i]} for i in range(len(STATUS_VALUES))]
 
 class BasicTests(unittest.TestCase):     
 
     def setUp(self) -> None:
-        
-        #Apiclient.send_get = Mock()
-        #TestrailLibrary.apiclient.Apiclient.Apiclient.send_get = Mock()
-        self.tr = TestrailLibrary.TestrailLibrary("f")
+        self.tr = TR("dummy")
         return super().setUp()
 
     @patch('TestrailLibrary.apiclient.Apiclient.send_get')
@@ -166,39 +60,65 @@ class BasicTests(unittest.TestCase):
         res = self.tr.get_project_by_name("some project")
         self.assertFalse(res)
 
-    @patch('TestrailLibrary.apiclient.Apiclient.send_get', Mock(return_value=GET_SUITE))
-    def test_get_suite(self):
-        res = self.tr.get_suite(GET_SUITE.get("id"))
+    @patch('TestrailLibrary.apiclient.Apiclient.send_get')
+    def test_get_suite(self, mock_get):
+        suites = SuitesResponse(10).suites
+        mock_get.return_value = suites[0]
+        res = self.tr.get_suite(suites[0].get("id"))
         self.assertTrue(res)
-        self.assertEqual(res.get('id'), GET_SUITE.get('id'))
+        self.assertEqual(res.get('id'), suites[0].get('id'))
 
-    @patch('TestrailLibrary.apiclient.Apiclient.send_get', Mock(return_value=GET_SUITES))
-    def test_get_suite_by_name(self):
-        res = self.tr.get_suite_by_name(17, GET_SUITES[0].get("name"))
+    @patch('TestrailLibrary.apiclient.Apiclient.send_get')
+    def test_get_suite_by_name(self, mock_get):
+        suites = SuitesResponse(2).suites
+        mock_get.return_value = suites
+        res = self.tr.get_suites_by_name(17, suites[0].get("name"))
         self.assertTrue(res)
-        self.assertEqual(res.get('id'), GET_SUITES[0].get('id'))
-        self.assertEqual(res.get('name'), GET_SUITES[0].get("name"))
+        self.assertEqual(res[0].get('id'), suites[0].get('id'))
+        self.assertEqual(res[0].get('name'), suites[0].get("name"))
 
-    @patch('TestrailLibrary.apiclient.Apiclient.send_get', Mock(return_value=GET_SUITES))
-    def test_get_suite_by_name_when_no_exists(self):
-        res = self.tr.get_suite_by_name(17, "some suite")
+    @patch('TestrailLibrary.apiclient.Apiclient.send_get')
+    def test_get_suite_by_name_when_no_exists(self, mock_get):
+        suites = SuitesResponse(10).suites
+        mock_get.return_value = suites
+        res = self.tr.get_suites_by_name(17, "some suite")
         self.assertFalse(res)
     
     @patch('TestrailLibrary.apiclient.Apiclient.send_get', Mock(return_value=[]))
     def test_get_suite_by_name_when_empty(self):
-        res = self.tr.get_suite_by_name(17, "some suite")
+        res = self.tr.get_suites_by_name(17, "some suite")
         self.assertFalse(res)
     
     @patch('TestrailLibrary.apiclient.Apiclient.send_get', Mock(return_value={"message":"error"}))
     def test_get_suite_by_name_when_error(self):
-        res = self.tr.get_suite_by_name(17, "some suite")
+        res = self.tr.get_suites_by_name(17, "some suite")
         self.assertFalse(res)
     
-    @patch('TestrailLibrary.apiclient.Apiclient.send_get', Mock(return_value=GET_SUITES))
-    def test_get_suites_in_project(self):
+    @patch('TestrailLibrary.apiclient.Apiclient.send_get')
+    def test_get_suite_by_name_when_duplicates(self, mock_get):
+        suites = SuitesResponse(10).suites
+        suites.append(suites[0])
+        mock_get.return_value = suites
+        with self.assertRaises(DuplicateException): 
+            res = self.tr.get_suites_by_name(17, suites[0].get("name"))
+    
+    @patch('TestrailLibrary.apiclient.Apiclient.send_get')
+    def test_get_suite_by_name_when_duplicates_and_expect(self, mock_get):
+        suites = SuitesResponse(10).suites
+        suites.append(suites[0])
+        mock_get.return_value = suites
+        self.tr.set_expect_duplicates(True)
+        res = self.tr.get_suites_by_name(17, suites[0].get("name"))
+        self.assertEqual(len(res), 2)
+        self.assertEqual(res[0].get("name"), res[1].get("name"))
+    
+    @patch('TestrailLibrary.apiclient.Apiclient.send_get')
+    def test_get_suites_in_project(self, mock_get):
+        suites = SuitesResponse(10).suites
+        mock_get.return_value = suites
         res = self.tr.get_suites_in_project(17)
         self.assertTrue(res)
-        self.assertEqual(res, GET_SUITES)
+        self.assertEqual(res, suites)
 
     @patch('TestrailLibrary.apiclient.Apiclient.send_get')
     def test_get_run(self, mock_get):
@@ -241,7 +161,6 @@ class BasicTests(unittest.TestCase):
         with self.assertRaises(DuplicateException): 
             res = self.tr.get_runs_by_name(17, runs.runs[0].get("name"))
         
-
     @patch('TestrailLibrary.apiclient.Apiclient.send_get', Mock(side_effect=[RunsResponse().get, 
                                                  RunsResponse(10, 250).get])) 
     def test_get_runs(self):
@@ -335,8 +254,17 @@ class BasicTests(unittest.TestCase):
         mock_get.return_value = cases.get
         with self.assertRaises(DuplicateException): 
             res = self.tr.get_cases_by_name(17, 1000, 1000, cases.cases[0].get("title"))
-        res = self.tr.get_cases_by_name(17, 1000, 1000, "New case 1")
-        self.assertFalse(res)
+
+    @patch('TestrailLibrary.apiclient.Apiclient.send_get')
+    def test_get_case_by_name_when_duplicates_and_expect(self, mock_get):
+        cases = CasesResponse(10)
+        new_cases = CasesResponse(1)
+        cases.cases.append(new_cases.cases[0])
+        mock_get.return_value = cases.get
+        self.tr.set_expect_duplicates(True)
+        res = self.tr.get_cases_by_name(17, 1000, 1000, cases.cases[0].get("title"))
+        self.assertEqual(len(res), 2)
+        self.assertEqual(res[0].get("name"), res[1].get("name"))
     
     @patch('TestrailLibrary.apiclient.Apiclient.send_get', Mock(side_effect=[CasesResponse().get, 
                                                 CasesResponse(10, offset=250).get]))
@@ -419,52 +347,59 @@ class BasicTests(unittest.TestCase):
         self.assertTrue(res)
         self.assertEqual(res.get('name'), "Test run 1") 
 
-    @patch('TestrailLibrary.apiclient.Apiclient.send_get', Mock(return_value=RunsResponse(10).get))
-    def test_add_run_when_duplicates(self):
-        res = self.tr.add_run(17, 1000, name="Test run 1", description="")
-        self.assertTrue(res)
-        self.assertEqual(res.get('name'), "Test run 1") 
-
     @patch('TestrailLibrary.apiclient.Apiclient.send_get')
     def test_add_run_when_duplicates(self, mock_get):
         runs = RunsResponse(10)
         runs.runs.append(runs.runs[0])
         mock_get.return_value = runs.get
         with self.assertRaises(DuplicateException): 
-            res = self.tr.add_run(17, 1000, name="Test run 1", description="")
+            res = self.tr.add_run(17, 1000, name=runs.runs[0].get("name"), description="")
     
-    @patch('TestrailLibrary.apiclient.Apiclient.send_post', Mock(return_value={"id": GET_SUITE.get('id')}))
+    @patch('TestrailLibrary.apiclient.Apiclient.send_get')
+    def test_add_run_when_duplicates_and_expected(self, mock_get):
+        runs = RunsResponse(10)
+        runs.runs.append(runs.runs[0])
+        mock_get.return_value = runs.get
+        self.tr.set_expect_duplicates(True)
+        res = self.tr.add_run(17, 1000, name=runs.runs[0].get("name"), description="")
+        self.assertFalse(res)
+    
+    @patch('TestrailLibrary.apiclient.Apiclient.send_post')
     @patch('TestrailLibrary.apiclient.Apiclient.send_get') 
-    def test_add_case(self, mock_get):
+    def test_add_case(self, mock_get, mock_post):
+        suites = SuitesResponse(2)
         cases = CasesResponse(10)
         sections = SectionsResponse(2)
         section_name = sections.sections[0].get("name")
+        mock_post.return_value = suites.suites[0]
         mock_get.side_effect = [
-            GET_SUITE, sections.get, cases.get
+            suites.suites[0], sections.get, cases.get
         ]
-        suite_id = GET_SUITE.get('id')
+        suite_id = suites.suites[0].get('id')
         res = self.tr.add_case(17, suite_id, "New Case", section_name=section_name)
         self.assertTrue(res)
-        self.assertEqual(res.get('id'), GET_SUITE.get('id')) 
-        self.assertEqual(res.get('title'), GET_SUITE.get('title')) 
+        self.assertEqual(res.get('id'), suites.suites[0].get('id')) 
+        self.assertEqual(res.get('title'), suites.suites[0].get('title')) 
     
     @patch('TestrailLibrary.apiclient.Apiclient.send_get')  
     def test_add_case_when_exists(self, mock_get):
         cases = CasesResponse(10)
+        suites = SuitesResponse(1)
         title = cases.cases[0].get("title")
         sections = SectionsResponse(2)
         section_name = sections.sections[0].get("name")
         case_id = cases.cases[0].get("id")
         mock_get.side_effect = [
-            GET_SUITE, sections.get, cases.get
+            suites.suites[0], sections.get, cases.get
         ]
-        res = self.tr.add_case(17, GET_SUITE.get("id"), title, section_name=section_name)
+        res = self.tr.add_case(17, suites.suites[0].get("id"), title, section_name=section_name)
         self.assertTrue(res)
         self.assertEqual(res.get("id"), case_id)
 
     @patch('TestrailLibrary.apiclient.Apiclient.send_get')  
     def test_add_case_when_duplicates(self, mock_get):
         cases = CasesResponse(10)
+        suites = SuitesResponse(1)
         new_cases = CasesResponse(1)
         new_case = new_cases.cases[0]
         new_case["id"] = 11
@@ -473,10 +408,10 @@ class BasicTests(unittest.TestCase):
         sections = SectionsResponse(2)
         section_name = sections.sections[0].get("name")
         mock_get.side_effect = [
-            GET_SUITE, sections.get, cases.get
+            suites.suites[0], sections.get, cases.get
         ]
         with self.assertRaises(DuplicateException):
-            res = self.tr.add_case(17, GET_SUITE.get("id"), title, section_name=section_name)
+            res = self.tr.add_case(17, suites.suites[0].get("id"), title, section_name=section_name)
     
 
     @patch('TestrailLibrary.apiclient.Apiclient.send_get', Mock(return_value=ResultsResponse(50).get)) 
@@ -543,10 +478,11 @@ class BasicTests(unittest.TestCase):
     @patch('TestrailLibrary.apiclient.Apiclient.send_get') 
     def test_set_status_on_test_run_using_suite_name(self, mock_get, mock_post):
         results = ResultsResponse(1)
+        suites = SuitesResponse(1)
         result = results.results[0]
         mock_post.return_value = result
-        mock_get.side_effect = [ GET_STATUSES, GET_SUITES, CasesResponse(10).get ]
-        res = self.tr.set_status_on_test_run(1, project_id=17, suite_name=GET_SUITES[0].get("name"), 
+        mock_get.side_effect = [ GET_STATUSES, suites.suites, CasesResponse(10).get ]
+        res = self.tr.set_status_on_test_run(1, project_id=17, suite_name=suites.suites[0].get("name"), 
             section_id=1000, test_id=5000, run_id=1 )
         self.assertTrue(res)
         self.assertEqual(res, result)
@@ -555,12 +491,13 @@ class BasicTests(unittest.TestCase):
     @patch('TestrailLibrary.apiclient.Apiclient.send_get') 
     def test_set_status_on_test_run_using_suite_and_section_name(self, mock_get, mock_post):
         results = ResultsResponse(1)
+        suites = SuitesResponse(2)
         result = results.results[0]
         sections = SectionsResponse(10)
         section = sections.sections[0]
         mock_post.return_value = result
-        mock_get.side_effect = [ GET_STATUSES, GET_SUITES, sections.get, CasesResponse(10).get ]
-        res = self.tr.set_status_on_test_run(1, project_id=17, suite_name=GET_SUITES[0].get("name"), 
+        mock_get.side_effect = [ GET_STATUSES, suites.suites, sections.get, CasesResponse(10).get ]
+        res = self.tr.set_status_on_test_run(1, project_id=17, suite_name=suites.suites[0].get("name"), 
             section_name=section.get("name"), test_id=5000, run_id=1 )
         self.assertTrue(res)
         self.assertEqual(res, result)
@@ -569,15 +506,16 @@ class BasicTests(unittest.TestCase):
     @patch('TestrailLibrary.apiclient.Apiclient.send_get') 
     def test_set_status_on_test_run_using_suite_and_section_and_test_name(self, mock_get, mock_post):
         results = ResultsResponse(1)
+        suites = SuitesResponse(2)
         result = results.results[0]
         sections = SectionsResponse(10)
         section = sections.sections[0]
         cases = CasesResponse(10)
         case = cases.cases[0]
         mock_post.return_value = result
-        mock_get.side_effect = [ GET_STATUSES, GET_SUITES, sections.get, cases.get, 
+        mock_get.side_effect = [ GET_STATUSES, suites.suites, sections.get, cases.get, 
                                  sections.get, cases.get, cases.get ]
-        res = self.tr.set_status_on_test_run(1, project_id=17, suite_name=GET_SUITES[0].get("name"), 
+        res = self.tr.set_status_on_test_run(1, project_id=17, suite_name=suites.suites[0].get("name"), 
             section_name=section.get("name"), test_name=case.get("title"), run_id=1 )
         self.assertTrue(res)
         self.assertEqual(res, result)
@@ -586,6 +524,7 @@ class BasicTests(unittest.TestCase):
     @patch('TestrailLibrary.apiclient.Apiclient.send_get') 
     def test_set_status_on_test_run_using_all_names(self, mock_get, mock_post):
         results = ResultsResponse(1)
+        suites = SuitesResponse(2)
         result = results.results[0]
         sections = SectionsResponse(10)
         section = sections.sections[0]
@@ -594,9 +533,9 @@ class BasicTests(unittest.TestCase):
         runs = RunsResponse(5)
         run = runs.runs[0]
         mock_post.return_value = result
-        mock_get.side_effect = [ GET_STATUSES, GET_SUITES, sections.get, cases.get, 
+        mock_get.side_effect = [ GET_STATUSES, suites.suites, sections.get, cases.get, 
                                  sections.get, cases.get, runs.get, cases.get ]
-        res = self.tr.set_status_on_test_run(1, project_id=17, suite_name=GET_SUITES[0].get("name"), 
+        res = self.tr.set_status_on_test_run(1, project_id=17, suite_name=suites.suites[0].get("name"), 
             section_name=section.get("name"), test_name=case.get("title"), run_name=run.get("name") )
         self.assertTrue(res)
         self.assertEqual(res, result)
@@ -605,12 +544,13 @@ class BasicTests(unittest.TestCase):
     @patch('TestrailLibrary.apiclient.Apiclient.send_get') 
     def test_set_status_on_test_run_using_section_name(self, mock_get, mock_post):
         results = ResultsResponse(1)
+        suites = SuitesResponse(2)
         result = results.results[0]
         sections = SectionsResponse(10)
         section = sections.sections[0]
         mock_post.return_value = result
         mock_get.side_effect = [ GET_STATUSES, sections.get, CasesResponse(10).get ]
-        res = self.tr.set_status_on_test_run(1, project_id=17, suite_id=GET_SUITES[0].get("id"), 
+        res = self.tr.set_status_on_test_run(1, project_id=17, suite_id=suites.suites[0].get("id"), 
             section_name=section.get("name"), test_id=5000, run_id=1 )
         self.assertTrue(res)
         self.assertEqual(res, result)
@@ -619,12 +559,13 @@ class BasicTests(unittest.TestCase):
     @patch('TestrailLibrary.apiclient.Apiclient.send_get') 
     def test_set_status_on_test_run_using_test_name(self, mock_get, mock_post):
         results = ResultsResponse(1)
+        suites = SuitesResponse(2)
         result = results.results[0]
         cases = CasesResponse(10)
         case = cases.cases[0]
         mock_post.return_value = result
         mock_get.side_effect = [ GET_STATUSES, cases.get, SectionsResponse(10).get, cases.get, cases.get ]
-        res = self.tr.set_status_on_test_run(1, project_id=17, suite_id=GET_SUITES[0].get("id"), 
+        res = self.tr.set_status_on_test_run(1, project_id=17, suite_id=suites.suites[0].get("id"), 
             section_id=1000, test_name=case.get("title"), run_id=1 )
         self.assertTrue(res)
         self.assertEqual(res, result)
@@ -633,13 +574,14 @@ class BasicTests(unittest.TestCase):
     @patch('TestrailLibrary.apiclient.Apiclient.send_get') 
     def test_set_status_on_test_run_using_run_name(self, mock_get, mock_post):
         results = ResultsResponse(1)
+        suites = SuitesResponse(2)
         result = results.results[0]
         cases = CasesResponse(10)
         runs = RunsResponse(5)
         run = runs.runs[0]
         mock_post.return_value = result
         mock_get.side_effect = [ GET_STATUSES, runs.get, cases.get ]
-        res = self.tr.set_status_on_test_run(1, project_id=17, suite_id=GET_SUITES[0].get("id"), 
+        res = self.tr.set_status_on_test_run(1, project_id=17, suite_id=suites.suites[0].get("id"), 
             section_id=1000, test_id=5000, run_name=run.get("name") )
         self.assertTrue(res)
         self.assertEqual(res, result)
@@ -657,7 +599,7 @@ class BasicTests(unittest.TestCase):
         cases.cases.append(new_case)
         mock_post.return_value = result
         mock_get.side_effect = [ GET_STATUSES, SectionsResponse(10).get, cases.get, cases.get ]
-        res = self.tr.set_status_on_test_run(1, project_id=17, suite_id=GET_SUITES[0].get("id"), 
+        res = self.tr.set_status_on_test_run(1, project_id=17, suite_id=100, 
             section_id=1000, test_name=case.get("title"), run_id=1 )
         self.assertTrue(res)
         self.assertEqual(res, result)
@@ -666,7 +608,7 @@ class BasicTests(unittest.TestCase):
     def test_set_status_on_test_run_using_wrong_status_id(self, mock_get): 
         mock_get.return_value = GET_STATUSES
         with self.assertRaises(Exception):
-            res = self.tr.set_status_on_test_run(8, project_id=17, suite_id=GET_SUITES[0].get("id"), 
+            res = self.tr.set_status_on_test_run(8, project_id=17, suite_id=100, 
                 section_id=1000, test_id=1, run_id=1 )
     
     @patch('TestrailLibrary.apiclient.Apiclient.send_post')
@@ -751,13 +693,15 @@ class BasicTests(unittest.TestCase):
     @patch('TestrailLibrary.apiclient.Apiclient.send_post')
     @patch('TestrailLibrary.apiclient.Apiclient.send_get')
     def test_delete_attachments_cleanup(self, mock_get, mock_post):
+        
         run = RunsResponse(1).runs[0]
         attachments = AttachmentsResponse(10)
         mock_get.return_value = attachments.get 
-        mock_post.side_effect = [{"attachment_id": attachments.attachments[i].get("id")} 
+        deleted_response = [{"attachment_id": attachments.attachments[i].get("id")} 
                         for i in range(len(attachments.attachments[:-7]))]
+        mock_post.side_effect = deleted_response
         res = self.tr.delete_attachments_cleanup(run.get("id"))
-        self.assertIsNone(res)
+        self.assertEqual(res, deleted_response)
 
 if __name__ == "__main__":
     unittest.main()
